package edu.uoc.helpDesk.bussinesslogic;

import java.util.List;

import javax.ejb.Remote;

import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.entities.Worker;

/**
 * Interfaz remoto de acceso a los métodos de la lógica de negocio del programa
 * HelpDesk.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
@Remote
public interface HelpDeskEngineer {

	/**
	 * Cierra un incidente con la fecha y hora actuales del sistema.
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 */
	public void closeIncident(Integer incidentId);

	/**
	 * Actualiza la solución dada a un incidente.
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 * @param incidentSolution
	 *            La solución.
	 */
	public void updateIncident(Integer incidentId, String incidentSolution);

	/**
	 * Localiza un incidente a través de su identificador.
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 * @return El incidente.
	 */
	public Incident findIncident(Integer incidentId);

	/**
	 * Devuelve un listado con todos los incidentes asignados a un ingeniero.
	 * 
	 * @param engineerId
	 *            El identificador del ingeniero.
	 * @return El listado de incidentes.
	 */
	public List<Incident> findIncidentsEngineer(Integer engineerId);

	/**
	 * Marca un incidente como "en proceso de solución".
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 */
	public void workIncident(Integer incidentId);

	/**
	 * Reabre un incidente ya cerrado.
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 */
	public void reopenIncident(Integer incidentId);

	/**
	 * Asigna un incidente a un ingeniero.
	 * 
	 * @param incidentId
	 *            El identificador del incidente.
	 * @param engineerId
	 *            El identificador del ingeniero.
	 */
	public void assignIncident(Integer incidentId, Integer engineerId);

	/**
	 * Devuelve un listado con todos los incidentes.
	 * 
	 * @return El listado de incidentes.
	 */
	public List<Incident> findAllIncidents();

	/**
	 * Devuelve un listado con todos los incidentes sin asignar.
	 * 
	 * @return El listado de incidentes.
	 */
	public List<Incident> findUnassignedIncidents();

	/**
	 * Comprueba que existe un ingeniero con el login y password pasados por
	 * parámetro.
	 * 
	 * @param login
	 *            El login.
	 * @param password
	 *            El password.
	 * @return El primer ingeniero cuyos datos coincidan.</br> null si no existe
	 *         ningún ingeniero con esos datos.
	 */
	public Engineer login(String login, String password);

	/**
	 * Devuelve un listado con todos los ingenieros.
	 * 
	 * @return El listado de ingenieros.
	 */
	public List<Engineer> findAllEngineers();

	/**
	 * Devuelve un listado con todos los trabajadores.
	 * 
	 * @return El listado de trabajadores.
	 */
	public List<Worker> findAllWorkers();

	/**
	 * Devuelve un listado con todos los incidentes notificados por un
	 * trabajador.
	 * 
	 * @param workerId
	 *            El identificador del trabajador.
	 * @return El listado de incidentes.
	 */
	public List<Incident> findIncidentsWorker(Integer workerId);
}
