package edu.uoc.helpDesk.bussinesslogic;

import java.util.Date;
import java.util.List;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.entities.Worker;

/**
 * Bean de sesión que implementa los métodos de la lógica de negocio. Accede a
 * la capa de datos a través del archivo de configuración persistence.xml.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
@Stateless
public class HelpDeskEngineerBean implements HelpDeskEngineer {

	/**
	 * El gestor de acceso a la capa de persistencia.
	 */
	@PersistenceContext(unitName = "JPADB")
	private EntityManager entityManager;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#login(java.lang.String,
	 * java.lang.String)
	 */
	@SuppressWarnings("unchecked")
	@Override
	public Engineer login(String login, String password) {
		Query query = entityManager
				.createQuery(
						"SELECT p FROM " + Engineer.class.getName()
								+ " p WHERE p.login LIKE :thisLogin "
								+ "AND p.password LIKE :thisPassword")
				.setParameter("thisLogin", login)
				.setParameter("thisPassword", password);
		List<Engineer> engineers = (List<Engineer>) query.getResultList();
		if (!engineers.isEmpty()) {
			return engineers.get(0);
		} else {
			return null;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#closeIncident(java.lang
	 * .Integer)
	 */
	@Override
	public void closeIncident(Integer incidentId) {
		Incident incident = findIncident(incidentId);
		incident.setIncidentClose(new Date());
		incident.setIncidentState(3);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#assignIncident(java.
	 * lang.Integer, java.lang.Integer)
	 */
	@Override
	public void assignIncident(Integer incidentId, Integer engineerId) {
		Engineer engineer = entityManager.find(Engineer.class, engineerId);
		Incident incident = findIncident(incidentId);
		incident.setEngineerId(engineer);
		incident.setIncidentState(1);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#workIncident(java.lang
	 * .Integer)
	 */
	@Override
	public void workIncident(Integer incidentId) {
		Incident incident = findIncident(incidentId);
		incident.setIncidentState(2);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#updateIncident(java.
	 * lang.Integer, java.lang.String)
	 */
	@Override
	public void updateIncident(Integer incidentId, String incidentSolution) {
		Incident incident = findIncident(incidentId);
		incident.setIncidentSolution(incidentSolution);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#reopenIncident(java.
	 * lang.Integer)
	 */
	@Override
	public void reopenIncident(Integer incidentId) {
		Incident incident = findIncident(incidentId);
		incident.setIncidentState(4);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findIncident(java.lang
	 * .Integer)
	 */
	@Override
	public Incident findIncident(Integer incidentId) {
		return entityManager.find(Incident.class, incidentId);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findIncidentsEngineer
	 * (java.lang.Integer)
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Incident> findIncidentsEngineer(Integer engineerId) {
		Engineer engineer = entityManager.find(Engineer.class, engineerId);
		Query query = entityManager.createQuery(
				"SELECT p from " + Incident.class.getName()
						+ " p WHERE p.engineerId LIKE :thisEngineer")
				.setParameter("thisEngineer", engineer);
		return (List<Incident>) query.getResultList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findIncidentsWorker(
	 * java.lang.Integer)
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Incident> findIncidentsWorker(Integer workerId) {
		Worker worker = entityManager.find(Worker.class, workerId);
		Query query = entityManager.createQuery(
				"SELECT p from " + Incident.class.getName()
						+ " p WHERE p.workerId LIKE :thisWorker").setParameter(
				"thisWorker", worker);
		return (List<Incident>) query.getResultList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findAllIncidents()
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Incident> findAllIncidents() {
		Query query = entityManager.createQuery("SELECT p from "
				+ Incident.class.getName() + " p");
		return (List<Incident>) query.getResultList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findUnassignedIncidents
	 * ()
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Incident> findUnassignedIncidents() {
		Query query = entityManager.createQuery("SELECT p from "
				+ Incident.class.getName() + " p WHERE p.incidentState = '0'");
		return (List<Incident>) query.getResultList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findAllEngineers()
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Engineer> findAllEngineers() {
		Query query = entityManager.createQuery("SELECT p from "
				+ Engineer.class.getName() + " p");
		return (List<Engineer>) query.getResultList();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer#findAllWorkers()
	 */
	@SuppressWarnings("unchecked")
	@Override
	public List<Worker> findAllWorkers() {
		Query query = entityManager.createQuery("SELECT p from "
				+ Worker.class.getName() + " p");
		return (List<Worker>) query.getResultList();
	}

}
