package edu.uoc.helpDesk.entities;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;

/**
 * Clase que almacena una entidad de datos de tipo Engineer o Ingeniero.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
@Entity
public class Engineer implements Serializable {
	private static final long serialVersionUID = 1L;

	/**
	 * Método de creación.
	 */
	public Engineer() {
		super();
	}

	/**
	 * El identificador del ingeniero. Clave foránea al identificador del
	 * trabajador de la clase Worker.
	 */
	@Id
	@OneToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "workerId")
	private Worker workerId;

	/**
	 * Login del ingeniero.
	 */
	private String login;

	/**
	 * Password del ingeniero.
	 */
	private String password;

	/**
	 * Perfil del ingeniero. Con valor "0" será un ingeniero normal, con valor
	 * "1" será un administrador.
	 */
	private int profile;

	/**
	 * Obtiene el ingeniero encargado de solucionar la incidencia. Se obtiene
	 * directamente el momento de realizar la petición (opción EAGER del método
	 * Fetch).
	 * 
	 * @return El ingeniero.
	 */
	public Worker getWorkerId() {
		return workerId;
	}

	/**
	 * Asigna el ingeniero.
	 * 
	 * @param workerId
	 *            El ingeniero.
	 */
	public void setWorkerId(Worker workerId) {
		this.workerId = workerId;
	}

	/**
	 * Obtiene el login del ingeniero.
	 * 
	 * @return El login del ingeniero.
	 */
	public String getLogin() {
		return login;
	}

	/**
	 * Asigna el login del ingeniero.
	 * 
	 * @param login
	 *            El login del ingeniero.
	 */
	public void setLogin(String login) {
		this.login = login;
	}

	/**
	 * Obtiene el password del ingeniero.
	 * 
	 * @return El password del ingeniero.
	 */
	public String getPassword() {
		return password;
	}

	/**
	 * Asigna el password del ingeniero.
	 * 
	 * @param password
	 *            El password del ingeniero.
	 */
	public void setPassword(String password) {
		this.password = password;
	}

	/**
	 * Obtiene el perfil del ingeniero.
	 * 
	 * @return El perfil del ingeniero.
	 */
	public int getProfile() {
		return profile;
	}

	/**
	 * Asigna el perfil del ingeniero.
	 * 
	 * @param profile
	 *            El perfil del ingeniero.
	 */
	public void setProfile(int profile) {
		this.profile = profile;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		return "Engineer [workerId=" + workerId + ", login=" + login
				+ ", profile=" + profile + "]";
	}
}
