package edu.uoc.helpDesk.command;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.form.SelectIncidentForm;
import edu.uoc.helpDesk.utility.BeanAccess;
import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.command.AbstractCommand;

/**
 * Comando que cierra una incidencia y le asigna como fecha de cierre la hora
 * actual del servidor.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class CloseIncidentCommand extends AbstractCommand {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#execute()
	 */
	public String execute() {

		// El formulario con los datos de entrada.
		SelectIncidentForm formBean = (SelectIncidentForm) getFormBean();

		// El bean de sesión.
		HelpDeskEngineer engineerBean = BeanAccess.getEngineerBean();

		// La incidencia a modificar.
		Incident incidente = engineerBean
				.findIncident(formBean.getIncidentId());

		// El estado anterior de la incidencia.
		int state = incidente.getIncidentState();

		/*
		 * Se comprueba que la incidencia esté asignada, en proceso de
		 * resolución o reabierta, situaciones en las cuales puede ser cerrada.
		 */
		if ((state == 1) || (state == 2) || (state == 4)) {

			// Se cierra la incidencia enviada en la petición.
			engineerBean.closeIncident(formBean.getIncidentId());

			// Se recupera la incidencia modificada.
			incidente = engineerBean.findIncident(formBean.getIncidentId());

			/*
			 * El parámetro source marca la última operación realizada, para
			 * mostrar un mensaje adecuado por pantalla.
			 */
			viewHelper.addParameter("source", "solved");

		} else {
			// No debe mostrarse ningún mensaje por pantalla.
			viewHelper.addParameter("source", "");
		}

		// Se añade la incidencia al ViewHelper.
		viewHelper.addParameter("incident", incidente);

		return Constants.SUCCESS;
	}
}
