package edu.uoc.helpDesk.command;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;
import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.form.LoginForm;
import edu.uoc.helpDesk.utility.BeanAccess;
import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.command.AbstractCommand;
import edu.uoc.myst.international.I18N;

/**
 * Comando que permite a un ingeniero identificarse ante la aplicación (realizar
 * un login) para poder utilizar sus servicios.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class LoginCommand extends AbstractCommand {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#execute()
	 */
	public String execute() {

		// El formulario con los datos de entrada.
		LoginForm formBean = (LoginForm) getFormBean();

		// El bean de sesión.
		HelpDeskEngineer engineerBean = BeanAccess.getEngineerBean();

		// Se llama a la lógica de sesión para realizar el login.
		Engineer engineer = engineerBean.login(formBean.getUsername(),
				formBean.getPassword());

		/*
		 * Si el ingeniero no es null es porque se ha identificado
		 * correctamente.
		 */
		if (engineer != null) {
			String level;

			// Si su perfil es "0" es un ingeniro normal.
			if (engineer.getProfile() == 0) {
				level = "engineer";

			} else {
				/*
				 * Si su perfil es diferente de "0" es un administrador o
				 * "root".
				 */
				level = "root";
			}

			/*
			 * Se añaden a los parámetros de sesión el nivel del ingeniero y su
			 * identificador.
			 */
			addSessionParameter("account", level);
			addSessionParameter("engineer", engineer.getWorkerId()
					.getWorkerId());
			return Constants.SUCCESS;

		} else {
			/*
			 * Si el ingeniero es igual a null es porque no se ha identificado
			 * correctamente (el usuario no existe, la contraseña no era la
			 * correcta, etc.)
			 * 
			 * Se muestra un mensaje no demasiado específico por pantalla y se
			 * devuelve un fallo.
			 */
			try {
				addSessionParameter("loginmessage", I18N.getString(
						"HelpDeskBundle", "wrongLogin",
						contextObject.getLocalization()));
			} catch (Exception e) {
				addSessionParameter("loginmessage",
						"Nombre de usuario o contrase\u00F1a err\u00F3neos.");
			}
			return Constants.FAIL;
		}
	}
}
