package edu.uoc.helpDesk.command;

import java.util.List;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;
import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.form.ModifyIncidentForm;
import edu.uoc.helpDesk.utility.BeanAccess;
import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.command.AbstractCommand;

/**
 * Comando que modifica una incidencia, asignando una propuesta de solución.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class ModifyIncidentCommand extends AbstractCommand {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#execute()
	 */
	public String execute() {

		// El formulario con los datos de entrada.
		ModifyIncidentForm formBean = (ModifyIncidentForm) getFormBean();

		// El bean de sesión.
		HelpDeskEngineer engineerBean = BeanAccess.getEngineerBean();

		// Se obtiene la solución pasada como parámetro en la petición.
		String solution = formBean.getIncidentSolution();

		// La incidencia a modificar.
		Incident incidente = engineerBean
				.findIncident(formBean.getIncidentId());

		/*
		 * Se comprueba que la incidencia no esté cerrada, único caso en que no
		 * debe ser modificada.
		 */
		if (incidente.getIncidentState() != 3) {

			/*
			 * Se comprueba que la solución no tenga más de 200 caracteres,
			 * tamaño máximo aceptado por la base de datos. En caso de ser
			 * superior, se recorta y se mantienen los 200 primeros caracteres.
			 */
			if (solution.length() > 200) {
				solution = solution.substring(0, 199);
			}

			/*
			 * Se actualiza la incidencia asignando la nueva solución. el
			 * identificador de la incidencia se obtiene de la petición.
			 */
			engineerBean.updateIncident(formBean.getIncidentId(), solution);

			// Se recupera la incidencia modificada.
			incidente = engineerBean.findIncident(formBean.getIncidentId());

			/*
			 * El parámetro source marca la última operación realizada, para
			 * mostrar un mensaje adecuado por pantalla.
			 */
			viewHelper.addParameter("source", "modified");

		} else {
			// No debe mostrarse ningún mensaje por pantalla.
			viewHelper.addParameter("source", "");
		}

		/* Si el ingeniero es un administrador se recupera un listado con todos
		 * los ingenieros y se añade al ViewHelper.
		 */
		if (getSessionParameter("account").equals("root")) {
			List<Engineer> ingenieros = engineerBean.findAllEngineers();
			viewHelper.addParameter("engineers", ingenieros);
		}		

		// Se añade la incidencia al ViewHelper.
		viewHelper.addParameter("incident", incidente);

		return Constants.SUCCESS;
	}
}
