package edu.uoc.helpDesk.command;

import java.util.List;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;
import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.form.SelectIncidentForm;
import edu.uoc.helpDesk.utility.BeanAccess;
import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.command.AbstractCommand;

/**
 * Comando que modifica una incidencia, marcándola como en proceso de
 * resolución.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class WorkIncidentCommand extends AbstractCommand {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#execute()
	 */
	public String execute() {

		// El formulario con los datos de entrada.
		SelectIncidentForm formBean = (SelectIncidentForm) getFormBean();

		// El bean de sesión.
		HelpDeskEngineer engineerBean = BeanAccess.getEngineerBean();

		// La incidencia a modificar.
		Incident incidente = engineerBean
				.findIncident(formBean.getIncidentId());

		// El estado anterior de la incidencia.
		int state = incidente.getIncidentState();

		/*
		 * Se comprueba que la incidencia esté asignada o reabierta, situaciones
		 * en las cuales puede ser marcada como en proceso de resolución.
		 */
		if ((state == 1) || (state == 4)) {

			/*
			 * Se marca la incidencia enviada como parámetro en la petición como
			 * en proceso de resolución.
			 */
			engineerBean.workIncident(formBean.getIncidentId());

			// Se recupera la incidencia modificada.
			incidente = engineerBean.findIncident(formBean.getIncidentId());

			/*
			 * El parámetro source marca la última operación realizada, para
			 * mostrar un mensaje adecuado por pantalla.
			 */
			viewHelper.addParameter("source", "inWork");
			
		} else {
			// No debe mostrarse ningún mensaje por pantalla.
						viewHelper.addParameter("source", "");
		}

		/* Si el ingeniero es un administrador se recupera un listado con todos
		 * los ingenieros y se añade al ViewHelper.
		 */
		if (getSessionParameter("account").equals("root")) {
			List<Engineer> ingenieros = engineerBean.findAllEngineers();
			viewHelper.addParameter("engineers", ingenieros);
		}		

		// Se añade la incidencia al ViewHelper.
		viewHelper.addParameter("incident", incidente);

		return Constants.SUCCESS;
	}
}
