package edu.uoc.helpDesk.exception;

import java.util.Locale;

import edu.uoc.myst.exception.MystException;
import edu.uoc.myst.international.I18N;

/**
 * Excepción causada cuando un ingeniero trata de acceder a recursos sobre los
 * cuales no tiene responsabilidad ni permisos.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class WrongEngineerAccessException extends MystException {

	private static final long serialVersionUID = 1L;

	/**
	 * El ingeniero sobre cuyos recursos se realiza la petición.
	 */
	private int resorcesEnginerId;
	
	/**
	 * El ingeniero identificado en la sesión.
	 */
	private int sessionEngineerId;

	/**
	 * Método de creación. Asigna el ingeniero y la petición.</p>
	 * 
	 * @param sessionEngineerId
	 *            El ingeniero sobre cuyos recursos se realiza la petición.
	 *            
	 *  @param resorcesEnginerId
	 *            El ingeniero identificado en la sesión.       
	 *            
	 */
	public WrongEngineerAccessException(int sessionEngineerId, int resorcesEnginerId) {
		this.sessionEngineerId = sessionEngineerId;
		this.resorcesEnginerId = resorcesEnginerId;
	}

	/* (non-Javadoc)
	 * @see edu.uoc.myst.exception.exceptions.MystException#getLocalizedMessage(java.util.Locale)
	 */
	public String getLocalizedMessage(Locale localization) {
		Object[] messageArguments = { sessionEngineerId, resorcesEnginerId };
		return I18N.getMessage("HelpDeskBundle", "wrongEngineer",
				messageArguments, localization);
	}
}
