package edu.uoc.helpDesk.exception;

import java.util.Locale;

import edu.uoc.myst.exception.MystException;
import edu.uoc.myst.international.I18N;

/**
 * Excepción causada cuando un ingeniero trata de acceder a una incidencia sobre
 * la cual no responsabilidades, ni permisos.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class WrongIncidentAccessException extends MystException {

	private static final long serialVersionUID = 1L;

	/**
	 * La incidencia sobre la cual se realiza la petición.
	 */
	private int incidentId;

	/**
	 * El ingeniero identificado en la sesión.
	 */
	private int engineerId;

	/**
	 * Método de creación. Asigna el ingeniero y la petición.</p>
	 * 
	 * @param incidentId
	 *            La incidencia sobre la cual se realiza la petición.
	 * 
	 * @param engineerId
	 *            El ingeniero identificado en la sesión.
	 * 
	 */
	public WrongIncidentAccessException(int incidentId, int engineerId) {
		this.incidentId = incidentId;
		this.engineerId = engineerId;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.myst.exception.exceptions.MystException#getLocalizedMessage(java
	 * .util.Locale)
	 */
	public String getLocalizedMessage(Locale localization) {
		Object[] messageArguments = { incidentId, engineerId };
		return I18N.getMessage("HelpDeskBundle", "wrongIncident",
				messageArguments, localization);
	}
}
