package edu.uoc.helpDesk.exception.handler;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Iterator;
import java.util.List;
import java.util.logging.Logger;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.exception.MystException;
import edu.uoc.myst.exception.handler.ExceptionHandler;
import edu.uoc.myst.view.ForwardView;
import edu.uoc.myst.view.View;

/**
 * Gestor de excepciones para excepciones de acceso erróneo.</p>
 * 
 * Guarda el mensaje de error en el log, pero no avisa al usuario, para que no
 * descubra peticiones válidas a las que no debe tener acceso.</p>
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class AccessExceptionHandler implements ExceptionHandler {

	static Logger logger = Logger.getLogger(AccessExceptionHandler.class
			.getName());

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.exception.ExceptionHandler#handle(java.util.List,
	 * edu.uoc.myst.core.ContextObject)
	 */
	public View handle(List<Throwable> exceptionList,
			ContextObject contextObject) {
		
		Iterator<Throwable> iter = exceptionList.iterator();
		Throwable e;
		StringWriter error;

		while (iter.hasNext()) {
			/*
			 * Se recorren todas las excepciones acontecidas y, de ser posible,
			 * se regionalizan.
			 */
			e = iter.next();
			if (e instanceof MystException) {
				/*
				 * Excepción basada en MystException, implementa el método de
				 * regionalización.
				 */
				logger.info(((MystException) e)
						.getLocalizedMessage(contextObject.getLocalization()));
			} else {
				/*
				 * Las excepciones que no heredan de MystException no
				 * regionalizan, se muestra su traza de error.
				 */
				error = new StringWriter();
				e.printStackTrace(new PrintWriter(error));
				logger.info(error.toString());
			}
		}
		View view = new ForwardView();
		return view;
	}
}
