package edu.uoc.helpDesk.exception.handler;

import java.util.List;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.exception.handler.ExceptionHandler;
import edu.uoc.myst.international.I18N;
import edu.uoc.myst.view.ForwardView;
import edu.uoc.myst.view.View;

/**
 * Gestor para excepciones de login.</p>
 * 
 * Guarda los mensajes de error en el elemento "loginmessage" de la sesión.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class LoginExceptionHandler implements ExceptionHandler {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.exception.ExceptionHandler#handle(java.util.List,
	 * edu.uoc.myst.core.ContextObject)
	 */
	public View handle(List<Throwable> exceptionList,
			ContextObject contextObject) {

		String message;

		/*
		 * Se regionaliza un mensaje de error de usurio y/o contraseña
		 * incorrectos, puesto que se sabe que el mensaje de error de la lista
		 * de excepciones solo haría una referencia genérica al filtro que ha
		 * fallado.
		 */
		try {
			message = I18N.getString("HelpDeskBundle", "badLog",
					contextObject.getLocalization());
		} catch (Exception e) {
			message = "El nombre de usuario y/o la contrase\u00F1a son err\u00F3neos.";
		}
		/*
		 * Se almacena el mensaje de error en un atributo de la sesión, puesto
		 * que el ViewHelper no estará disponible en el primer acceso a la
		 * página de login.
		 */
		contextObject.getSession().setAttribute("loginmessage", message);
		View view = new ForwardView();
		return view;
	}
}
