package edu.uoc.helpDesk.filter;

import edu.uoc.helpDesk.exception.WrongEngineerAccessException;
import edu.uoc.helpDesk.form.FindIncidentsEngineerForm;
import edu.uoc.myst.filter.AbstractFilter;
import edu.uoc.myst.auxiliary.Constants;

/**
 * Filtro de entrada que comprueba que el ingeniero que realiza una petición
 * sobre un recurso es propietario del mismo, o bien es administrador.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class IsEngineerOrRootFilter extends AbstractFilter {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#execute()
	 */
	public String execute() throws WrongEngineerAccessException {

		// El formulario de entrada.
		FindIncidentsEngineerForm formBean = (FindIncidentsEngineerForm) getFormBean();

		/*
		 * Se comprueba si el identificador de ingeniero de la petición coincide
		 * con el ingeniero actual, cuyos datos están almacenados como
		 * parámetros de la sesión. También se comprueba en la sesión si el
		 * ingeniero actual es "root", o administrador.
		 */
		if (((String) getSessionParameter("account")).equals("root")
				|| (Integer) getSessionParameter("engineer") == formBean
						.getEngineerId()) {
			return Constants.SUCCESS;

		} else {
			/*
			 * Si no cumple las condiciones es proque se ha intentado un acceso
			 * ilegal a los recursos del ingeniero objetivo.
			 */
			throw new WrongEngineerAccessException(formBean.getEngineerId(),
					(Integer) getSessionParameter("engineer"));
		}
	}
}
