package edu.uoc.helpDesk.filter;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;
import edu.uoc.helpDesk.entities.Engineer;
import edu.uoc.helpDesk.entities.Incident;
import edu.uoc.helpDesk.exception.WrongIncidentAccessException;
import edu.uoc.helpDesk.form.SelectIncidentForm;
import edu.uoc.helpDesk.utility.BeanAccess;
import edu.uoc.myst.filter.AbstractFilter;
import edu.uoc.myst.auxiliary.Constants;

/**
 * Filtro de entrada que comprueba que el ingeniero que realiza una petición
 * sobre una incidencia es el gestor de la misma, o bien es administrador.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class IsOwnerOrRootFilter extends AbstractFilter {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#execute()
	 */
	public String execute() throws WrongIncidentAccessException {

		// El formulario de entrada.
		SelectIncidentForm formBean = (SelectIncidentForm) getFormBean();

		// El bean de sesión.
		HelpDeskEngineer engineerBean = BeanAccess.getEngineerBean();

		// La incidencia sobre la que se realiza una petición.
		Incident incident = engineerBean.findIncident(formBean.getIncidentId());

		// Se comprueba que se accede a una incidencia existente.
		if (incident != null) {

			// El ingeniero asignado a solventar la incidencia.
			Engineer petitionEngineer = incident.getEngineerId();

			/*
			 * Se comprueba en los parámtros de sesión si el ingeniero es
			 * administrador. o "root".
			 */
			if (((String) getSessionParameter("account")).equals("root")) {
				return Constants.SUCCESS;

			} else {
				if (petitionEngineer != null) {

					/*
					 * Si la incidencia tiene un ingeniero asignado, se
					 * comprueba que sea el ingeniero actual, cuyos datos se
					 * encuentran en los parámetros dela sesión.
					 */
					if ((Integer) getSessionParameter("engineer") == petitionEngineer
							.getWorkerId().getWorkerId()) {
						return Constants.SUCCESS;
					}
				}
			}
		}

		/*
		 * En cualquier otro caso se ha intentado realizar un acceso ilegal
		 * sobre la incidencia.
		 */
		throw new WrongIncidentAccessException(formBean.getIncidentId(),
				(Integer) getSessionParameter("engineer"));
	}
}
