package edu.uoc.helpDesk.utility;

import java.util.Properties;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer;

/**
 * Clase que proporciona acceso a la interfaz remota del bean de sesión
 * HelpDeskEngineer.
 * 
 * @author Miguel Souto Bartolomé
 * @version 1.0 13/01/2014
 * 
 */
public class BeanAccess {

	/**
	 * El contexto inicial.
	 */
	private static Context initialContext;

	/**
	 * Obtiene la interfaz remota del bean de sesión a HelpDeskEngineer, a
	 * partir del contexto inicial y el nombre de búsqueda JNDI.
	 * 
	 * @return La interfaz del bean de sesión.
	 */
	public static HelpDeskEngineer getEngineerBean() {
		Context context = null;
		HelpDeskEngineer bean = null;
		try {
			context = getInitialContext();
			String lookupName = getLookupNameEngineer();
			bean = (HelpDeskEngineer) context.lookup(lookupName);

		} catch (NamingException e) {
			e.printStackTrace();
		}
		return bean;
	}

	/**
	 * Obtiene el contexto inicial para conectarse al bean de sesión. Si el
	 * contexto no existe, lo crea.
	 * 
	 * @return El contexto.
	 * @throws NamingException
	 */
	private static Context getInitialContext() throws NamingException {
		if (initialContext == null) {
			Properties properties = new Properties();
			properties.put(Context.URL_PKG_PREFIXES,
					"org.jboss.ejb.client.naming");
			initialContext = new InitialContext(properties);
		}
		return initialContext;
	}

	/**
	 * Crea el nombre de búsqueda JNDI del bean de sesión. En caso de querer
	 * desplegar la aplicación de forma diferente a la predeterminada habrá que
	 * modificar los valores de las variables appName y distinctName.
	 * 
	 * @return El nombre de búsqueda.
	 */
	private static String getLookupNameEngineer() {
		/*
		 * appName es el nombre del EAR desplegado, sin la extensión. Dado que
		 * se ha optado por desplegar el bean de sesión y la aplicación por
		 * separado, el appName es una cadena vacía. us will be an empty string
		 */
		String appName = "";

		/*
		 * Nombre sin la extensión del JAR desplegado que contiene el bean de
		 * sesión.
		 */
		String moduleName = "helpDesk-EJB-1.0";

		/*
		 * Si se quiere dar un nombre diferente a cada despliegue, se especifica
		 * en esta variable. En este caso no se da ningún nombre, por lo que
		 * equivale a la cadena vacía.
		 */
		String distinctName = "";

		// El nombre de la clase que implementa el bean de sesión.
		String beanName = "HelpDeskEngineerBean";

		// Nombre de la interfaz remota del bean de sesión.
		final String interfaceName = "edu.uoc.helpDesk.bussinesslogic.HelpDeskEngineer";

		// Nombre completo para buscar.
		String name = "ejb:" + appName + "/" + moduleName + "/" + distinctName
				+ "/" + beanName + "!" + interfaceName;
		return name;
	}
}
