package edu.uoc.myst.command;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.international.I18N;
import edu.uoc.myst.view.ViewHelper;

/**
 * Clase abstracta que permite definir el comando asociado a una peticin
 * HTTP.</p>
 * 
 * Todo comando que utilice el framework Myst puede extender esta clase,
 * implementar la interfaz {@link Command}, o respetar las especificaciones
 * indicadas en la interfaz.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public abstract class AbstractCommand implements Command {

	

	/**
	 * El formulario de entrada asociado.
	 */
	protected Object formBean;

	/**
	 * El ViewHelper de ayuda a las vistas asociado.
	 */
	protected ViewHelper viewHelper;

	/**
	 * El contexto de la peticin HTTP.
	 */
	protected ContextObject contextObject;

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#setFormBean(java.lang.Object)
	 */
	public void setFormBean(Object formBean) {
		this.formBean = formBean;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#getFormBean()
	 */
	public Object getFormBean() {
		return formBean;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.myst.command.Command#setViewHelper(edu.uoc.myst.view.ViewHelper)
	 */
	public void setViewHelper(ViewHelper viewHelper) {
		this.viewHelper = viewHelper;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#getViewHelper()
	 */
	public ViewHelper getViewHelper() {
		return viewHelper;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.myst.command.Command#setContextObject(edu.uoc.myst.core.ContextObject
	 * )
	 */
	public void setContextObject(ContextObject contextObject) {
		this.contextObject = contextObject;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#getContextObject()
	 */
	public ContextObject getContextObject() {
		return this.contextObject;
	}
	
	/* (non-Javadoc)
	 * @see edu.uoc.myst.command.Command#addSessionParameter(java.lang.String, java.lang.Object)
	 */
	public void addSessionParameter(String name, Object value) {    
		contextObject.getSession().setAttribute(name, value);		
	}

	/* (non-Javadoc)
	 * @see edu.uoc.myst.command.Command#getSessionParameter(java.lang.String)
	 */
	public Object getSessionParameter(String name) {
		return contextObject.getSession().getAttribute(name);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#localize(java.lang.String)
	 */
	public String localize(String string) {
		String result = string;
		if (string != null) {
			try {
				result = I18N.getString(this.getClass().getName(), string,
						contextObject.getLocalization());
			} catch (Exception e) {
				contextObject.addException(e);
			}
		}
		return result;
	}
}
