package edu.uoc.myst.core;

import java.io.IOException;
import java.util.logging.Logger;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.uoc.myst.configuration.ConfigurationManager;
import edu.uoc.myst.configuration.xml.MystConfiguration;

/**
 * Controlador frontal del framework Myst.</p>
 * 
 * Durante la inicializacin del servlet carga la configuracin a travs de
 * {@link ConfigurationManager}, e instancia el {@link ApplicationController} o
 * despachador.</p>
 * 
 * Adems, gestiona todas las peticiones de los clientes de la aplicacin
 * usuaria de Myst. Para ello genera una configuracin del contexto o
 * {@link ContextObject}, donde guarda los datos de la peticin, y la enva al
 * despachador para delegar el tratamiento de la peticin.</p>
 * 
 * Implementa el patrn FrontController.</p>
 * 
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public class FrontController extends HttpServlet {
	private static final long serialVersionUID = 1L;
	static Logger logger = Logger.getLogger(FrontController.class.getName());

	/**
	 * El despachador del framework.
	 */
	private ApplicationController applicationController;

	/**
	 * Configuracin de la aplicacin obtenida del fichero XML asociado.
	 */
	private MystConfiguration applicationConfiguration;

	/**
	 * El contexto del servlet.
	 */
	private ServletContext servletContext;

	/**
	 * Constructor predeterminado.
	 */
	public FrontController() {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.GenericServlet#init()
	 */
	public void init() throws ServletException {
		try {
			/*
			 * Se obtiene el contexto del Servlet, se instancia el espachador y
			 * se carga el archivo de configuracin.
			 */
			servletContext = getServletContext();
			applicationConfiguration = ConfigurationManager
					.load(getServletConfig());
			applicationController = new ApplicationController(
					applicationConfiguration);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.servlet.http.HttpServlet#doGet(javax.servlet.http.HttpServletRequest
	 * , javax.servlet.http.HttpServletResponse)
	 */
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		ContextObject contextObject;
		try {
			/*
			 * Se crea el objeto de contexto y se pasa la peticin al
			 * despachador.
			 */
			logger.info("Comienzo de la peticin");
			contextObject = new ContextObject(request, response, servletContext);
			applicationController.process(contextObject);
		} finally {
			logger.info("Fin de la peticin");
		}

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * javax.servlet.http.HttpServlet#doPost(javax.servlet.http.HttpServletRequest
	 * , javax.servlet.http.HttpServletResponse)
	 */
	protected void doPost(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		doGet(request, response);
	}
}
