package edu.uoc.myst.exception;

import java.util.Locale;

import edu.uoc.myst.international.I18N;

/**
 * Excepcin causada cuando el resultado de un comando no tiene ninguna vista
 * local ni global definida en el archivo de configuracin.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public class NoViewException extends MystException {

	private static final long serialVersionUID = 1L;

	/**
	 * El resultado de la ejecucin del comando.
	 */
	private String result;

	/**
	 * El nombre del comando.
	 */
	private String command;

	/**
	 * Mtodo de creacin. Asigna el resultado y el comando.</p>
	 * 
	 * @param result
	 *            El resultado de la ejecucin del comando.
	 * @param command
	 *            El nombre del comando.
	 */
	public NoViewException(String result, String command) {
		this.result = result;
		this.command = command;
	}

	/**
	 * Obtiene de un bundle la versin regionalizada del mensaje de error.</p>
	 * 
	 * @param localization
	 *            La regin.
	 * @return El mensaje regionalizado.
	 */
	public String getLocalizedMessage(Locale localization) {
		Object[] messageArguments = { result, command };
		return I18N.getMessage("ExceptionBundle", "noView", messageArguments,
				localization);
	}
}