package edu.uoc.myst.exception.handler;

import java.util.List;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.view.View;

/**
 * Interfaz que permite gestionar una excepcin sucedida en la aplicacin o el
 * framework.</p>
 * 
 * Tpicamente, un gestor de errores debe escribir la informacin que quiera
 * mostrar en una vista en el mapa del {@link edu.uoc.myst.view.ViewHelper
 * ViewHelper}, disponible a travs del mtodo
 * {@link edu.uoc.myst.core.ContextObject#getViewHelper() getViewHelper()} del
 * contexto de la peticin HTTP.</p>
 * 
 * Todo gestor de excepciones que utilice el framework Myst debe implementar
 * esta interfaz.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public interface ExceptionHandler {

	/**
	 * Mtodo que gestiona los errores y devuelve una vista para mostrarlos
	 * 
	 * @param list La lista de errores.
	 * @param contextObject el contexto de la peticin HTTP.
	 * @return La vista para mostrar los errores.
	 */
	View handle(List<Throwable> list, ContextObject contextObject);
}