package edu.uoc.myst.exception.handler;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.exception.MystException;
import edu.uoc.myst.view.ForwardView;
import edu.uoc.myst.view.View;
import edu.uoc.myst.view.ViewHelper;

/**
 * Gestor de excepciones que obtiene los mensajes regionalizados de todas las
 * excepciones sucedidas para mostrarlos por pantalla. Para ello utiliza el
 * mtodo {@link MystException#getLocalizedMessage(java.util.Locale)
 * getLocalizedMessage(Locale)}, disponible en todas las}excepciones que hereden
 * de {@link MystException}.</p>
 * 
 * Guarda dichos mensajes en el elemento "Exceptions" del mapa de elementos del
 * ViewHelper, disponible en el contexto de la peticin HTTP.</p>
 * 
 * Se distribuye conjuntamente a la vista "internationalError.jsp", que presenta
 * adecuadamente dicha informacin.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public class InternationalExceptionHandler implements ExceptionHandler {

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.exception.ExceptionHandler#handle(java.util.List,
	 * edu.uoc.myst.core.ContextObject)
	 */
	public View handle(List<Throwable> exceptionList,
			ContextObject contextObject) {

		ViewHelper helper = new ViewHelper(contextObject);
		List<String> exceptions = new ArrayList<String>();
		Iterator<Throwable> iter = exceptionList.iterator();
		Throwable e;
		StringWriter error;

		while (iter.hasNext()) {
			/*
			 * Se recorren todas las excepciones acontecidas y, de ser posible,
			 * se regionalizan.
			 */
			e = iter.next();
			if (e instanceof MystException) {
				/*
				 * Excepcin basada en MystException, implementa el mtodo de
				 * regionalizacin.
				 */
				exceptions.add(((MystException) e)
						.getLocalizedMessage(contextObject.getLocalization()));
			} else {
				/*
				 * Las excepciones que no heredan de MystException no
				 * regionalizan, se muestra su traza de error.
				 */
				error = new StringWriter();
				e.printStackTrace(new PrintWriter(error));
				exceptions.add(error.toString());
			}
		}
		// Se aaden las excepciones al ViewHelper y se devuelve una vista.
		helper.addParameter("Exceptions", exceptions);
		View view = new ForwardView();
		return view;
	}
}
