package edu.uoc.myst.filter;

import edu.uoc.myst.core.ContextObject;

/**
 * Clase abstracta que permite definir un filtro asociado a un comando.</p>
 * 
 * Todo filtro que utilice el framework Myst puede extender esta clase,
 * implementar la interfaz {@link Filter}, o respetar las especificaciones
 * indicadas en la interfaz.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public abstract class AbstractFilter implements Filter {

	/**
	 * El formulario de entrada o ViewHelper con los datos.
	 */
	protected Object formBean;

	/**
	 * El contexto de la peticin HTTP.
	 */
	protected ContextObject contextObject;

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#setFormBean(java.lang.Object)
	 */
	public void setFormBean(Object formBean) {
		this.formBean = formBean;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#getFormBean()
	 */
	public Object getFormBean() {
		return formBean;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.myst.filter.Filter#setContextObject(edu.uoc.myst.core.ContextObject
	 * )
	 */
	public void setContextObject(ContextObject contextObject) {
		this.contextObject = contextObject;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#getContextObject()
	 */
	public ContextObject getContextObject() {
		return this.contextObject;
	}
	
	/* (non-Javadoc)
	 * @see edu.uoc.myst.filter.Filter#addSessionParameter(java.lang.String, java.lang.Object)
	 */
	public void addSessionParameter(String name, Object value) {    
		contextObject.getRequest().getSession().setAttribute(name, value);		
	}
	
	/* (non-Javadoc)
	 * @see edu.uoc.myst.filter.Filter#getSessionParameter(java.lang.String)
	 */
	public Object getSessionParameter(String name) {
		return contextObject.getRequest().getSession().getAttribute(name);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.filter.Filter#addException(java.lang.Exception)
	 */
	public void addException(Exception exception) {
		contextObject.addException(exception);
	}
}
