package edu.uoc.myst.filter;

import edu.uoc.myst.core.ContextObject;

/**
 * Interfaz que permite definir un filtro asociado a un comando.</p>
 * 
 * Todo filtro que utilice el framework Myst puede implementar esta clase,
 * extender la clase abstracta {@link AbstractFilter}, o implementar un objeto
 * POJO desde cero.</p>
 * 
 * Si dicho objeto POJO debe tener acceso al contexto de la peticin HTTP, tiene
 * que definir el mtodo pblico {@link #setContextObject(ContextObject)} . Si
 * debe tener acceso al formulario, bien sea el {@link edu.uoc.myst.form.Form
 * Form} de entrada, en el caso de los filtros de entrada, o el objeto
 * {@link edu.uoc.myst.view.ViewHelper ViewHelper}, para los filtros de salida,
 * teine que definir en ambos casos el mtodo pblico
 * {@link #setFormBean(Object)}. En cualquier caso debe definir el mtodo
 * execute(), donde se especificar la lgica.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public interface Filter {

	/**
	 * Asigna el formulario.
	 * 
	 * @param formBean
	 *            El formulario.
	 */
	public void setFormBean(Object formBean);

	/**
	 * Devuelve el formulario.
	 * 
	 * @return El formulario.
	 */
	public Object getFormBean();

	/**
	 * Asigna el contexto de la peticin HTTP.
	 * 
	 * @param contextObject
	 *            El contexto de la peticin HTTP.
	 */
	public void setContextObject(ContextObject contextObject);

	/**
	 * Devuelve el contexto de la peticin HTTP.
	 * 
	 * @return El contexto de la peticin HTTP.
	 */
	public ContextObject getContextObject();

	/**
	 * Guarda una excepcin en el contexto de la peticin HTTP.
	 * 
	 * @param exception
	 *            La excepcin.
	 */
	public void addException(Exception exception);
	
	/**
	 * Aade un parmetro a la sesin.
	 * 
	 * @param name
	 *            El nombre del parmetro.
	 * @param value
	 *            El valor del parmetro.
	 */
	public void addSessionParameter(String name, Object value);

	/**
	 * Obtiene un parmetro de la sesin.
	 * 
	 * @param name
	 *            El nombre del parmetro.
	 * @return El valor del parmetro.
	 */
	public Object getSessionParameter(String name);

	/**
	 * Ejecuta la lgica del filtro.
	 * 
	 * @return {@link edu.uoc.myst.auxiliary.Constants#SUCCESS
	 *         Constants.SUCCESS} si el resultado es correcto, o
	 *         {@link edu.uoc.myst.auxiliary.Constants#FAIL Constants.FAIL} si
	 *         es incorrecto
	 * @throws Exception
	 */
	public String execute() throws Exception;

}
