package edu.uoc.myst.form;

import edu.uoc.myst.core.ContextObject;
import edu.uoc.myst.international.I18N;

/**
 * Clase abstracta que permite definir el formulario asociado a un comando.</p>
 * 
 * Todo formulario que utilice el framework Myst puede extender esta clase,
 * implementar la interfaz {@link Form}, o respetar las especificaciones
 * indicadas en la interfaz.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public abstract class AbstractForm implements Form {

	/**
	 * El contexto de la peticin HTTP.
	 */
	protected ContextObject contextObject;

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * edu.uoc.myst.form.Form#setContextObject(edu.uoc.myst.core.ContextObject)
	 */
	public void setContextObject(ContextObject contextObject) {
		this.contextObject = contextObject;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.form.Form#getContextObject()
	 */
	public ContextObject getContextObject() {
		return this.contextObject;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see edu.uoc.myst.command.Command#localize(java.lang.String)
	 */
	public String localize(String string) {
		String result = string;
		if (string != null) {
			try {
				result = I18N.getString(this.getClass().getName(), string,
						contextObject.getLocalization());
			} catch (Exception e) {
				contextObject.addException(e);
			}
		}
		return result;
	}

}
