package edu.uoc.myst.form;

import edu.uoc.myst.core.ContextObject;

/**
 * Interfaz que permite definir el formulario asociado a un comando.</p>
 * 
 * Todo formulario que utilice el framework Myst puede implementar esta clase,
 * extender la clase abstracta {@link AbstractForm}, o respetar las siguientes
 * especificaciones:</p>
 * 
 * <ul>
 * <li>Debe tener un conjunto de atributos igual al de los parmetros de la
 * peticin HTTP asociada, con los mismos nombres.</li>
 * <li>Debe definir mtodos pblicos setter y getter para todos sus atributos.</li>
 * </ul>
 * 
 * Si adems quiere tener acceso al contexto de la peticin HTTP, debe definir
 * el mtodo pblico {@link #setContextObject(ContextObject)}</p>
 * 
 * Form es muy similar a un bean Java, pero no es necesario que sea
 * serializable.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public interface Form {

	/**
	 * Asigna el contexto de la peticin HTTP.
	 * 
	 * @param contextObject
	 *            El contexto.
	 */
	public void setContextObject(ContextObject contextObject);

	/**
	 * Devuelve el contexto de la peticin HTTP.
	 * 
	 * @return El contexto.
	 */
	public ContextObject getContextObject();

	/**
	 * Devuelve la versin regionalizada de un String.</p>
	 * 
	 * Debe existir un bundle con el mismo nombre que este formulario, o se
	 * generar una excepcin.</p>
	 * 
	 * @param string
	 *            El String.
	 * @return La versin regionalizada del String.
	 */
	public String localize(String string);

}
