package edu.uoc.myst.view;

import java.io.IOException;

import javax.servlet.ServletException;

import edu.uoc.myst.core.ContextObject;

/**
 * Interfaz que permite definir las diferentes vistas. Toda vista que utilice el
 * framework Myst debe implementar esta clase, o extender la clase abstracta
 * {@link AbstractView}.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public interface View {

	/**
	 * Obtiene la pgina a mostrar.
	 * 
	 * @return La pgina.
	 */
	public String getNext();

	/**
	 * Asigna la pgina a mostrar.
	 * 
	 * @param next
	 *            La pgina
	 */
	public void setNext(String next);

	/**
	 * Muestra la vista en el navegador. Cada diferente implementacin de
	 * {@link View} lo realizar de la forma que considere adecuada.
	 * 
	 * @param viewHelper
	 *            Objeto de ayuda con la informacin de la lgica del negocio.
	 * @param contextObject
	 *            Contexto de la peticin HTTP.
	 * @throws ServletException
	 * @throws IOException
	 */
	public void show(ViewHelper viewHelper, ContextObject contextObject)
			throws ServletException, IOException;
}
