package edu.uoc.myst.view.taglib;

import java.util.Locale;

import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;

import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.auxiliary.RegExTools;
import edu.uoc.myst.exception.NoParameterException;
import edu.uoc.myst.exception.NoPathException;
import edu.uoc.myst.exception.WrongPatternException;
import edu.uoc.myst.view.ViewHelper;

/**
 * Tag que permite acceder a un elemento individual del mapa del objeto
 * ViewHelper asociado al comando. La sintaxis de uso en una peticin JSP es la
 * siguiente:</p>
 * 
 * &lt;myst:form element="elemento"/></p>
 * 
 * Donde elemento es la ruta al elemento que se quiere obtener.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * @see edu.uoc.myst.view.ViewHelper
 * 
 */
public class FormTag extends TagSupport {

	private static final long serialVersionUID = 7581585970831122828L;

	/**
	 * Objeto ViewHelper asociado al comando.
	 */
	private ViewHelper viewHelper;

	/**
	 * Elemento del ViewHelper a obtener.
	 */
	private String element;

	/**
	 * Recoge el nombre del elemento definido en el parmetro "element" de la
	 * peticin JSP.
	 * 
	 * @param element
	 *            El nombre del elemento a obtener.
	 */
	public void setElement(String element) {
		this.element = element;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
	 */
	public int doStartTag() throws JspException {
		String salida;
		try {
			salida = getElement();
			/*
			 * Si sucede una excepcin se regionaliza para mostrarla por
			 * pantalla.
			 */
		} catch (WrongPatternException e) {
			salida = e.getLocalizedMessage((Locale) pageContext.getSession()
					.getAttribute(Constants.LOCALIZATION));
		} catch (NoPathException e) {
			salida = e.getLocalizedMessage((Locale) pageContext.getSession()
					.getAttribute(Constants.LOCALIZATION));
		}

		if (salida == null) {
			// Si la salida es nula se genera un mensaje de error regionalizado.
			NoParameterException excp = new NoParameterException(element);
			salida = excp.getLocalizedMessage((Locale) pageContext.getSession()
					.getAttribute(Constants.LOCALIZATION));
		}
		
		try {
			//Se trata de mostrar la salida en la pgina
			pageContext.getOut().write(salida);
			
		} catch (Exception e) {
			// Si sucede un error se lanza uan excepcin JSP.
			throw new JspException(e);
		}
		return SKIP_BODY;
	}

	/**
	 * Obtiene el objeto de ViewHelper definido en el parmetro "element" de la
	 * peticin JSP.
	 * 
	 * @return El elemento solicitado en el parmetro "element"
	 * @throws WrongPatternException
	 * @throws NoPathException
	 */
	private String getElement() throws WrongPatternException, NoPathException {
		viewHelper = (ViewHelper) pageContext.getSession().getAttribute(
				Constants.VIEWHELPER);
		return String.valueOf((RegExTools.getElement(element,
				viewHelper.getParametersMap())));
	}
}
