package edu.uoc.myst.view.taglib;

import java.util.logging.Logger;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.*;

import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.auxiliary.RegExTools;
import edu.uoc.myst.exception.NoPathException;
import edu.uoc.myst.exception.WrongPatternException;
import edu.uoc.myst.view.ViewHelper;

/**
 * Tag que permite asignar a una variable un objeto del mapa del ViewHelper. La
 * sintaxis de uso en una peticin JSP es la siguiente:</p>
 * 
 * &lt;myst:set var="variable" element="elemento"/></p>
 * 
 * Donde elemento es la ruta del objeto que se quiere obtener, y variable la
 * variable que almacenar el objeto. Esta etiqueta permite evitar accesos
 * repetidos a un mismo objeto.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * @see edu.uoc.myst.view.ViewHelper
 * 
 */
public class SetTag extends TagSupport {

	private static final long serialVersionUID = 7581585970831122828L;
	static Logger logger = Logger.getLogger(SetTag.class.getName());

	/**
	 * Objeto ViewHelper asociado al comando.
	 */
	private ViewHelper viewHelper;

	/**
	 * Variable que almacena el objeto.
	 */
	private String var;

	/**
	 * Ruta del objeto.
	 */
	private String element;

	/**
	 * Recoge la variable que almacena el objeto.
	 * 
	 * @param var
	 *            La variable.
	 */
	public void setVar(String var) {
		this.var = var;
	}

	/**
	 * Recoge la ruta del objeto que se quiere asignar.
	 * 
	 * @param element
	 *            El nombre del vector a iterar.
	 */
	public void setElement(String element) {
		this.element = element;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.servlet.jsp.tagext.TagSupport#doStartTag()
	 */
	public int doStartTag() throws JspException {
		try {
			// Se intenta asignar el valor de la variable.
			pageContext.setAttribute(var, getObject());
			
			/*
			 * Si sucede una excepcin se regionaliza para mostrarla por
			 * pantalla y se lanza una excepcin JSP.
			 */
		} catch (WrongPatternException e) {
			throw new JspException(e.getLocalizedMessage(), e);
		} catch (NoPathException e) {
			throw new JspException(e.getLocalizedMessage(), e);
		}		
		return SKIP_BODY;
	}
	/**
	 * Obtiene el objeto del mapa del ViewHelper.
	 * 
	 * @return El vector.
	 * @throws WrongPatternException
	 * @throws NoPathException 
	 */
	private String getObject() throws WrongPatternException, NoPathException {
		viewHelper = (ViewHelper) pageContext.getSession().getAttribute(
				Constants.VIEWHELPER);
		return String.valueOf(RegExTools.getElement(element,
				viewHelper.getParametersMap())) ;
	}
}
