package command;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import edu.uoc.myst.auxiliary.Constants;
import edu.uoc.myst.view.ViewHelper;
import form.NonInheritedTestForm;
import form.ObjectoNegocio;

/**
 * Comando de tipo POJO, que utiliza un form y el ViewHelper, porlo que debe
 * definir mtodos getter y setter para ambos.</p>
 * 
 * Aade objetos de varios tipos al ViewHelper para mostrar el correcto
 * funcionamiento de los tags del framework. Los objetos tambin sern
 * procesados, segn define la configuracin de la aplicacin, por el filtro
 * InternationalFormatFilter.</p>
 * 
 * @author Miguel Souto Bartolom
 * @version 1.0 13/01/2014
 * 
 */
public class NonInheritedCommand {

	/**
	 * El form asociado al comando.
	 */
	protected Object formBean;

	/**
	 * El ViewHelper asociado al comando.
	 */
	protected ViewHelper viewHelper;

	/**
	 * Asigna el form al comando.
	 * 
	 * @param formBean
	 *            el form.
	 */
	public void setFormBean(Object formBean) {
		this.formBean = formBean;
	}

	/**
	 * Obtiene el form del comando.
	 * 
	 * @return El form.
	 */
	public Object getFormBean() {
		return formBean;
	}

	/**
	 * Asigna el ViewHelper al comando.
	 * 
	 * @param viewHelper
	 */
	public void setViewHelper(ViewHelper viewHelper) {
		this.viewHelper = viewHelper;
	}

	/**
	 * Obtiene el ViewHelper del comando.
	 * 
	 * @return El ViewHelper.
	 */
	public ViewHelper getViewHelper() {
		return viewHelper;
	}

	/**
	 * Mtodo llamado por el framework para ejecutar la lgica del comando. En
	 * este caso se lee un parmetro recibido pro el form, y se aaden varios
	 * objetos al ViewHelper.
	 * 
	 * @return El mensaje FAIL, aunque le mtodo se ejecuta correctamente.
	 */
	public String execute() {

		// Se obtiene el formulario asociado al comando.
		NonInheritedTestForm formBean = (NonInheritedTestForm) getFormBean();

		// Se obtiene el nmero del formulario.
		long integer = formBean.getNumero();

		// Se aade el nmero como String y como nmero al ViewHelper
		viewHelper.addParameter("numeroString", String.valueOf(integer));
		viewHelper.addParameter("numero", integer);

		// Se aade la fecha actual al ViewHelper.
		Date fecha = new Date();
		viewHelper.addParameter("fecha", fecha);

		/*
		 * Se aade una lista de tres objetos conformes con la definicin de un
		 * form al ViewHelper. Estos objetos podrn ser accedidos desde los
		 * tags, y tambin internacionalizados automticamente por el filtro
		 * InternationalFormatFilter.
		 */
		int[] myIntArray = { 1, 2, 3 };
		ObjectoNegocio objeto1 = new ObjectoNegocio(10, "Soy el objeto 1",
				myIntArray, -3.5);
		ObjectoNegocio objeto2 = new ObjectoNegocio(12, "Yo el objeto 2",
				myIntArray, -7);
		ObjectoNegocio objeto3 = new ObjectoNegocio(13, "Y yo el 3",
				myIntArray, -7);
		List<ObjectoNegocio> lista = new ArrayList<ObjectoNegocio>();
		lista.add(objeto1);
		lista.add(objeto2);
		lista.add(objeto3);
		viewHelper.addParameter("objetosNegocio", lista);

		/*
		 * Se devuelve el mensaje FAIL, para comprobar que se puede usar al
		 * gusto del programador.
		 */
		return Constants.FAIL;
	}
}
